Module api_check

Module api_check 

Enums

ApiVerdict
What comparing the public API against the baseline concluded.

Functions

disagrees
A verdict of Breaking only disagrees with the commits when those commits did not already ask for a major.
run